@@ -9,10 +9,12 @@
 #' @export
 #'
 #' @example /inst/examples/example_getCranDescription.R
-getCranDescription <- function(pkg, repos = getOption("repos"),
-                               type = "source",
-                               pkgs = pkgDep(pkg, repos = repos, type = type)) {
-
+getCranDescription <- function(
+  pkg,
+  repos = getOption("repos"),
+  type = "source",
+  pkgs = pkgDep(pkg, repos = repos, type = type)
+) {
   if (getRversion() >= "3.4.1") {
     pdb <- tools::CRAN_package_db()
     pdb[match(pkgs, pdb$Package), ]
