@@ -13,24 +13,36 @@ pkgFileExt <- function(type) {
 
 
 getPkgVersFromFile <- function(file) {
-  file <- grep("\\.(tar\\.gz|zip|tgz)$", basename(as.character(file)), value = TRUE)
+  file <- grep(
+    "\\.(tar\\.gz|zip|tgz)$",
+    basename(as.character(file)),
+    value = TRUE
+  )
   if (length(file)) {
     file <- sapply(strsplit(file, "\\.tar\\.gz"), "[[", 1)
     file <- sapply(strsplit(file, "\\.zip"), "[[", 1)
     file <- sapply(strsplit(file, "\\.tgz"), "[[", 1)
-    pkg  <- sapply(strsplit(file, "_"), "[[", 1)
+    pkg <- sapply(strsplit(file, "_"), "[[", 1)
     vers <- sapply(strsplit(file, "_"), "[[", 2)
-    df <- data.frame(package = pkg, version = vers, stringsAsFactors = FALSE, row.names = NULL)
-    df <- df[order(df$package),]
+    df <- data.frame(
+      package = pkg,
+      version = vers,
+      stringsAsFactors = FALSE,
+      row.names = NULL
+    )
+    df <- df[order(df$package), ]
     row.names(df) <- seq_len(nrow(df))
     df
   } else {
-    data.frame(package = character(0), version = character(0), stringsAsFactors = FALSE)
+    data.frame(
+      package = character(0),
+      version = character(0),
+      stringsAsFactors = FALSE
+    )
   }
 }
 
 
-
 readDescription <- function(file) {
   stopifnot(file.exists(file))
   trimSpaces <- function(x) {
@@ -41,9 +53,12 @@ readDescription <- function(file) {
     clean <- function(x) gsub("\n", " ", x)
     if (is.null(d$Depends)) d$Depends <- NA else d$Depends <- clean(d$Depends)
     if (is.null(d$Imports)) d$Imports <- NA else d$Imports <- clean(d$Imports)
-    if (is.null(d$Suggests)) d$Suggests <- NA else d$Suggests <- clean(d$Suggests)
-    if (is.null(d$LinkingTo)) d$LinkingTo <- NA else d$LinkingTo <- clean(d$LinkingTo)
-    if (is.null(d$Enhances)) d$Enhances <- NA else d$Enhances <- clean(d$Enhances)
+    if (is.null(d$Suggests)) d$Suggests <- NA else
+      d$Suggests <- clean(d$Suggests)
+    if (is.null(d$LinkingTo)) d$LinkingTo <- NA else
+      d$LinkingTo <- clean(d$LinkingTo)
+    if (is.null(d$Enhances)) d$Enhances <- NA else
+      d$Enhances <- clean(d$Enhances)
     d
   }
   dcf <- read.dcf(file)
@@ -53,15 +68,25 @@ readDescription <- function(file) {
 }
 
 
-
 addPackageListing <- function(pdb = pkgAvail(), dcf, warnings = TRUE) {
   pkgName <- dcf[["Package"]]
   #   pkgRow <- match(pkgName, rownames(pdb))
   pkgRow <- match(pkgName, pdb[, "Package"])
-  newRow <- with(dcf,
-                 c(Package, Version, NA,
-                   Depends, Imports, LinkingTo, Suggests, Enhances, License,
-                   rep(NA, 8)))
+  newRow <- with(
+    dcf,
+    c(
+      Package,
+      Version,
+      NA,
+      Depends,
+      Imports,
+      LinkingTo,
+      Suggests,
+      Enhances,
+      License,
+      rep(NA, 8)
+    )
+  )
   if (!is.na(pkgRow)) {
     pdb[pkgRow, ] <- newRow
     if (warnings) {
@@ -75,12 +100,16 @@ addPackageListing <- function(pdb = pkgAvail(), dcf, warnings = TRUE) {
 }
 
 
-
 # from https://stackoverflow.com/questions/13163248 Possible to override the
 # blocking of a package's (re-)installation after it has been required/loaded?
 
 #' @importFrom httr GET stop_for_status content
-readDescriptionGithub <- function(repo, username = NULL, branch = "master", quiet = TRUE) {
+readDescriptionGithub <- function(
+  repo,
+  username = NULL,
+  branch = "master",
+  quiet = TRUE
+) {
   # browser()
   if (!is.null(username)) repo <- paste(username, repo, sep = "/")
   pkg <- sprintf("https://github.com/%s/raw/%s/DESCRIPTION", repo, branch)
@@ -94,7 +123,6 @@ readDescriptionGithub <- function(repo, username = NULL, branch = "master", quie
 }
 
 
-
 #' Add DESCRIPTION information from package on github.
 #'
 #' Downloads the DESCRIPTION file from a package on github, parses the fields
@@ -113,8 +141,15 @@ readDescriptionGithub <- function(repo, username = NULL, branch = "master", quie
 #'
 #' @example /inst/examples/example_addPackageListingGithub.R
 addPackageListingGithub <- function(
-  pdb = pkgAvail(), repo, username = NULL, branch = "main"
+  pdb = pkgAvail(),
+  repo,
+  username = NULL,
+  branch = "main"
 ) {
-  desc <- readDescriptionGithub(repo = repo, username = username, branch = branch)
+  desc <- readDescriptionGithub(
+    repo = repo,
+    username = username,
+    branch = branch
+  )
   addPackageListing(pdb, desc)
 }
