@@ -20,19 +20,20 @@
 #' @family dependency functions
 #'
 #' @example inst/examples/example_plot.pkgDepGraph.R
-#'   
+#'
 plot.pkgDepGraph <- function(
-  x, pkgsToHighlight,
+  x,
+  pkgsToHighlight,
   main = paste(attr(x, "pkgs"), collapse = ", "),
   legendPosition = c(-1.2, -1),
   shape = "circle",
   vertex.size = 8,
   cex = 1,
-  ...)
-{
+  ...
+) {
   class(x) <- "igraph"
   plotColours <- c("grey80", "orange")
-  if(missing("pkgsToHighlight")) {
+  if (missing("pkgsToHighlight")) {
     pkgsToHighlight <- attr(x, "pkgs")
   }
 
@@ -41,7 +42,13 @@ plot.pkgDepGraph <- function(
   vFont <- 1 + topLevel
   vShape <- c("none", shape)[1 + topLevel]
 
-  edgeColor <- c(Imports = "red", Depends = "orange", Suggests = "grey80", Enhances = "blue", LinkingTo = "black")
+  edgeColor <- c(
+    Imports = "red",
+    Depends = "orange",
+    Suggests = "grey80",
+    Enhances = "blue",
+    LinkingTo = "black"
+  )
   eColor <- edgeColor[igraph::edge_attr(x, "type")]
 
   typesInGraph <- unique(igraph::edge_attr(x, "type"))
@@ -51,33 +58,36 @@ plot.pkgDepGraph <- function(
   par(mai = rep(0.25, 4))
   # browser()
 
-  igraph::plot.igraph(x, vertex.size = vertex.size,
-       edge.arrow.size = 0.5,
-       edge.color = eColor,
-       vertex.label.cex = cex,
-       vertex.label.color = "black",
-       vertex.color = vColor,
-       vertex.shape = vShape,
-       vertex.label.font = vFont,
-       xlim = c(-1.5, 1)
+  igraph::plot.igraph(
+    x,
+    vertex.size = vertex.size,
+    edge.arrow.size = 0.5,
+    edge.color = eColor,
+    vertex.label.cex = cex,
+    vertex.label.color = "black",
+    vertex.color = vColor,
+    vertex.shape = vShape,
+    vertex.label.font = vFont,
+    xlim = c(-1.5, 1)
   )
   pch1 <- rep(19, length(plotColours))
-  pch2 <- rep(-8594, length(edgeColor))  #https://www.alanwood.net/unicode/arrows.html
+  pch2 <- rep(-8594, length(edgeColor)) #https://www.alanwood.net/unicode/arrows.html
   yjust <- function(x) 0.5 * (x + 1)
   xjust <- function(x) 1
 
-
   # Edge legend
-  if(!is.null(legendPosition)) {
-    legend(x = legendPosition[1],
-           y = legendPosition[2],
-           xjust = xjust(legendPosition[1]),
-           yjust = yjust(legendPosition[2]),
-           legend = names(edgeColor),
-           col = edgeColor,
-           pch = pch2,
-           y.intersp = 0.75,
-           cex = cex)
+  if (!is.null(legendPosition)) {
+    legend(
+      x = legendPosition[1],
+      y = legendPosition[2],
+      xjust = xjust(legendPosition[1]),
+      yjust = yjust(legendPosition[2]),
+      legend = names(edgeColor),
+      col = edgeColor,
+      pch = pch2,
+      y.intersp = 0.75,
+      cex = cex
+    )
   }
   title(main, cex = cex)
 }
