@@ -1,12 +1,20 @@
 # Thin wrapper around utils::download.packages
-download_packages <- function(pkgs, destdir, available, repos, contriburl, type, quiet){
+download_packages <- function(
+  pkgs,
+  destdir,
+  available,
+  repos,
+  contriburl,
+  type,
+  quiet
+) {
   utils::download.packages(
     pkgs = pkgs,
     destdir = destdir,
     available = available,
     repos = repos,
     contriburl = contriburl,
-    type = type, 
+    type = type,
     quiet = quiet
   )
 }
@@ -14,7 +22,5 @@ download_packages <- function(pkgs, destdir, available, repos, contriburl, type,
 # Thin wrapper around write_PACKAGES
 write_packages <- function(dir, type, r_version) {
   r_version <- twodigitRversion(r_version)
-  tools::write_PACKAGES(dir = dir, type = type) 
+  tools::write_PACKAGES(dir = dir, type = type)
 }
-
-
